``foreground`` – Application of foregrounds with bandpass
=========================================================

.. automodule:: mflike.foreground

``Foreground`` class content
-----------------------------

.. autoclass:: mflike.Foreground
   :exclude-members: initialize
   :members:
   :show-inheritance:
   :private-members:
   :member-order: bysource

.. autoclass:: mflike.BandpowerForeground
   :exclude-members: initialize
   :members:
   :show-inheritance:
   :private-members:
   :member-order: bysource
